psychopy_ext.exp.Task.get_behav_df — psychopy_ext 0.5.4 documentation
Author: Jonas Kubilius
Description: A framework for a rapid reproducible design, analysis and plotting of experiments in neuroscience and psychology

# psychopy_ext.exp.Task.get_behav_df

`Task.` `get_behav_df`(pattern='%s')

  Extracts data from files for data analysis.

  Kwargs: | pattern (str, default: ‘%s’) A string with formatter information. Usually it contains a path to where data is and a formatter such as ‘%s’ to indicate where participant ID should be incorporated.
  Returns: | A pandas.DataFrame of data for the requested participants.